@@ -328,7 +328,6 @@ sub apache_conf {
     my $cgibin  = $self->config_data('cgibin');
     my $tmp     = $self->config_data('tmp');
     my $cgiroot = basename($cgibin);
-    my $docs    = basename($dir);
     my $perl5lib= $self->added_to_INC;
     my $inc      = $perl5lib ? "SetEnv PERL5LIB \"$perl5lib\"" : '';
     my $fcgi_inc = $perl5lib ? "-initial-env PERL5LIB=$perl5lib"        : '';
@@ -338,8 +337,8 @@ sub apache_conf {
         : '';
 
     return <<END;
-Alias        "/$docs/i/" "$tmp/images/"
-Alias        "/$docs"    "$dir"
+Alias        "/gbrowse2/i/" "$tmp/images/"
+Alias        "/gbrowse2"    "$dir"
 ScriptAlias  "/gb2"      "$cgibin"
 
 <Directory "$dir">
@@ -856,11 +855,12 @@ configuration files, and static image/support files will be installed.
 One or more of the config options can be set on the command 
 line when first running perl Build.PL:
 
-  perl Build.PL --conf=/etc/growse2 \            # config files
-                --htdocs=/var/www/gbrowse2   \   # static files
-                --cgibin=/usr/lib/cgi-bin/gb2 \  # CGI directory
-                --wwwuser=www-data \             # apache user
-                --portdemo=8000 \                # demo web site port
+  perl Build.PL --conf=/etc/gbrowse2          \  # config files
+                --htdocs=/var/www/gbrowse2    \  # static files
+                --cgibin=/usr/lib/cgi-bin/gb2 \  # CGI executables
+                --wwwuser=www-data            \  # apache user
+                --tmp=/var/tmp/gbrowse2       \  # temporary data
+                --portdemo=8000               \  # demo web site port
                 --apachemodules=/usr/lib/apache2/modules  # apache loadable modules
 
 =item reconfig
